@@ -9,7 +9,7 @@
  * #  Verwendung in anderen Programmen bzw. Programmiersprachen benutzt     #
  * #  werden.                                                               #
  * #                                                                        #
- * #  Copyright (C) 2002-2011 Michael Plugge <m.plugge@hs-mannheim.de>      #
+ * #  Copyright (C) 2002-2014 Michael Plugge <m.plugge@hs-mannheim.de>      #
  * #                                                                        #
  * #  Dieses Programm ist freie Software; Sie drfen es unter den           #
  * #  Bedingungen der GNU Lesser General Public License, wie von der Free   #
@@ -46,67 +46,30 @@
 #ifndef KONTO_CHECK_H_INCLUDED
 #define KONTO_CHECK_H_INCLUDED
 
-/* 
- * ##########################################################################
- * # Hier eine Info der Flessabank zur IBAN-Berechnung (abgerufen 13.6.12   #
- * # von http://www.flessabank.de/aktuell.php?akt=149)                      #
- * #                                                                        #
- * # Aktuelles Bankleitzahl/BIC                                             #
- * #                                                                        #
- * # Im Rahmen eines umfassenden Konsolidierungsprojekts der Deutschen      #
- * # Bundesbank und der Europischen Zentralbank werden immer mehr Filialen #
- * # der Deutschen Bundesbank geschlossen. Dabei wird auch die aktuelle     #
- * # Bankleitzahlenlogik fr die Deutsche Bundesbank berarbeitet.          #
- * #                                                                        #
- * # Um als FLESSABANK dieser vernderten Situation gerecht zu werden,      #
- * # haben wir uns entschlossen, unsere Bankleitzahlenstruktur zu           #
- * # vereinfachen und auf die zentrale Bankleitzahl 793 301 11 umzustellen. #
- * # Ihre Kontonummern bleiben dabei unverndert gltig!                    #
- * #                                                                        #
- * # Betroffen sind hiervon folgende Bankleitzahlen:                        #
- * # 700 301 11 (Niederlassung Mnchen)                                     #
- * # 763 301 11 (Niederlassung Erlangen)                                    #
- * # 770 301 11 (Niederlassung Bamberg)                                     #
- * # 783 301 11 (Niederlassung Coburg)                                      #
- * # 840 301 11 (Niederlassung Meiningen)                                   #
- * #                                                                        #
- * # Fr die Bereiche Internet-Banking und girocard ist bereits heute nur   #
- * # die Bankleitzahl 793 301 11 gltig. Auch Ihre IBAN (International Bank #
- * # Account Number = Internationale Kontonummer) wird ausschlielich mit   #
- * # der Bankleitzahl 793 301 11 erstellt. Wir teilen Ihnen diese zusammen  #
- * # mit unserem BIC (Bank Identifier Code = Bankkennung) auf jedem         #
- * # Kontoauszug mit.                                                       #
- * #                                                                        #
- * # Update zur Flessa-Bank (abgerufen 28.10.13): Die obigen Bankleitzahlen #
- * # haben in der aktuellen BLZ-Datei das Lschflag gesetzt und als         #
- * # Nachfolge-BLZ die 79330111 eingetragen. Damit erbrigt sich die        #
- * # Korrektur fr die Flessa-Bank.                                         #
- * ##########################################################################
- */
-
-#define FLESSA_KORREKTUR 0
-
 /* IBAN-Regeln benutzen (gltig ab 3.6.2013) */
 #define USE_IBAN_RULES 1
 
    /* nderungen der Prfziffermethoden zum 9. September 2013 erzwingen
-    * (bei 0 werden sie abhngig vom Datum aktiviert).
+    * (bei 0 werden sie abhngig vom Datum aktiviert; aktuell nicht benutzt).
    */ 
 #define FORCE_AENDERUNGEN_2013_09 0
 
-   /* die neue Version der Regel 20 wird zum 9. Dezember in den offiziellen IBAN-Regeln verffentlicht;
-    * die Bundesbank hat jedoch schon die Regelversion am 28. August verffentlicht, mit der Bitte, sie
-    * mglichst schon zum 9. September einzusetzen. Durch die neue Regelversion werden die Flle mit dem
-    * Rckgabewert IBAN_AMBIGUOUS_KTO komplett eliminiert.
+   /* Falls EXTRA_BLZ_REGEL auf 1 gesetzt wird, wird beim IBAN-Test
+    * unterschieden ob eine Regel ignoriert wurde, die nur eine BLZ ersetzt,
+    * oder eine andere Regel. Die Variante wenn nur eine BLZ ersetzt wird, wird
+    * von cKonto als richtig angesehen.
+    *
+    * Bei einer Nachfrage bei den 17 in Frage kommenden Banken bekam ich von
+    * zehn Banken Antworten. Von diesen sagte nur eine, da (aktuell) die
+    * "alten" IBANs noch akzeptiert wrden, die neun anderen sehen eine solche
+    * IBAN jedoch als fehlerhaft an. In konto_check wird daher das alte
+    * Verhalten beibehalten, solche IBANs als Fehler zu deklarieren. Wenn das
+    * folgende Makro auf 1 gesetzt wird, gibt es verschiedene Rckgabewerte fr
+    * Regelverste mit nur BLZ-Ersetzung und andere Regeln. Auf diese Weise
+    * kann das Verhalten von cKonto in Benutzerprogrammen nachgebildet werden.
     */
 
-#define DB_NEUE_VERSION 1  /* bei 1: neue Version der DB-Regel benutzen */
-
-/* Debug-Version fr iban_gen in Perl aktivieren (zur Ausgabe der benutzten
- * Prfziffermethode in iban_gen()). Dies ist nur mglich, falls das Makro
- * DEBUG auf 1 gesetzt ist.
- */
-#define PERL_IBAN_DBG 1
+#define EXTRA_BLZ_REGEL 1
 
 /* Das Makro DEFAULT_ENCODING legt die Ausgabe-Kodierung fr die Funktion
  * kto_check_retval2txt() und die Blocks Name, Kurzname und Ort aus der
@@ -207,7 +170,7 @@
  * ######################################################################
  */
 
-#ifdef _WIN32
+#if _WIN32>0 || _WIN64>0
 #  if USE_CDECL
 #    if BUILD_DLL /* DLL kompilieren */
 #      define DLL_EXPORT __declspec (dllexport)
@@ -258,7 +221,7 @@
 
 #define DEFAULT_LUT_NAME "blz.lut","blz.lut2f","blz.lut2"
 
-#if _WIN32>0
+#if _WIN32>0 || _WIN64>0
 #define DEFAULT_LUT_PATH ".","C:","C:\\Programme\\konto_check"
 #else
 #define DEFAULT_LUT_PATH ".","/usr/local/etc","/etc","/usr/local/bin","/opt/konto_check"
@@ -327,6 +290,7 @@
 #define LUT2_VOLLTEXT_IDX            24
 #define LUT2_IBAN_REGEL              25
 #define LUT2_IBAN_REGEL_SORT         26
+#define LUT2_BIC_H_SORT              27
 
 #define LUT2_2_BLZ                  101
 #define LUT2_2_FILIALEN             102
@@ -354,6 +318,7 @@
 #define LUT2_2_VOLLTEXT_IDX         124
 #define LUT2_2_IBAN_REGEL           125
 #define LUT2_2_IBAN_REGEL_SORT      126
+#define LUT2_2_BIC_H_SORT           127
 
 #define LUT2_DEFAULT                501
 
@@ -370,6 +335,15 @@ extern const char *lut2_feld_namen[256];
  */
 
 #undef FALSE
+#define INVALID_BIQ_INDEX                     -149
+#define ARRAY_INDEX_OUT_OF_RANGE              -148
+#define IBAN_ONLY_GERMAN                      -147
+#define INVALID_PARAMETER_TYPE                -146
+#define BIC_ONLY_GERMAN                       -145
+#define INVALID_BIC_LENGTH                    -144
+#define IBAN_CHKSUM_OK_RULE_IGNORED_BLZ       -143
+#define IBAN_CHKSUM_OK_KC_NOT_INITIALIZED     -142
+#define IBAN_CHKSUM_OK_BLZ_INVALID            -141
 #define IBAN_CHKSUM_OK_NACHFOLGE_BLZ_DEFINED  -140
 #define LUT2_NOT_ALL_IBAN_BLOCKS_LOADED       -139
 #define LUT2_NOT_YET_VALID_PARTIAL_OK         -138
@@ -406,31 +380,6 @@ extern const char *lut2_feld_namen[256];
 #define KTO_CHECK_NO_DEFAULT_BLOCK            -107
 #define KTO_CHECK_KEY_NOT_FOUND               -106
 #define LUT2_NO_LONGER_VALID_BETTER           -105
-#define DTA_SRC_KTO_DIFFERENT                 -104
-#define DTA_SRC_BLZ_DIFFERENT                 -103
-#define DTA_CR_LF_IN_FILE                     -102
-#define DTA_INVALID_C_EXTENSION               -101
-#define DTA_FOUND_SET_A_NOT_C                 -100
-#define DTA_FOUND_SET_E_NOT_C                  -99
-#define DTA_FOUND_SET_C_NOT_EXTENSION          -98
-#define DTA_FOUND_SET_E_NOT_EXTENSION          -97
-#define DTA_INVALID_EXTENSION_COUNT            -96
-#define DTA_INVALID_NUM                        -95
-#define DTA_INVALID_CHARS                      -94
-#define DTA_CURRENCY_NOT_EURO                  -93
-#define DTA_EMPTY_AMOUNT                       -92
-#define DTA_INVALID_TEXT_KEY                   -91
-#define DTA_EMPTY_STRING                       -90
-#define DTA_MARKER_A_NOT_FOUND                 -89
-#define DTA_MARKER_C_NOT_FOUND                 -88
-#define DTA_MARKER_E_NOT_FOUND                 -87
-#define DTA_INVALID_SET_C_LEN                  -86
-#define DTA_INVALID_SET_LEN                    -85
-#define DTA_WAERUNG_NOT_EURO                   -84
-#define DTA_INVALID_ISSUE_DATE                 -83
-#define DTA_INVALID_DATE                       -82
-#define DTA_FORMAT_ERROR                       -81
-#define DTA_FILE_WITH_ERRORS                   -80
 #define INVALID_SEARCH_RANGE                   -79
 #define KEY_NOT_FOUND                          -78
 #define BAV_FALSE                              -77
@@ -536,6 +485,7 @@ extern const char *lut2_feld_namen[256];
 #define OK_HYPO_REQUIRES_KTO                    23
 #define OK_KTO_REPLACED_NO_PZ                   24
 #define OK_UNTERKONTO_ATTACHED                  25
+#define OK_SHORT_BIC_USED                       26
 
 #define MAX_BLZ_CNT 30000  /* maximale Anzahl BLZ's in generate_lut() */
 
@@ -924,6 +874,7 @@ DLL_EXPORT int lut_multiple_i(int b,int *cnt,int **p_blz,char ***p_name,char ***
 
    /* Funktionen, um einzelne Felder zu bestimmen (Rckgabe direkt) */
 DLL_EXPORT int lut_blz(char *b,int zweigstelle);
+DLL_EXPORT int lut_blz_i(int b,int zweigstelle);
 DLL_EXPORT int lut_filialen(char *b,int *retval);
 DLL_EXPORT int lut_filialen_i(int b,int *retval);
 DLL_EXPORT const char *lut_name(char *b,int zweigstelle,int *retval);
@@ -938,6 +889,8 @@ DLL_EXPORT int lut_pan(char *b,int zweigstelle,int *retval);
 DLL_EXPORT int lut_pan_i(int b,int zweigstelle,int *retval);
 DLL_EXPORT const char *lut_bic(char *b,int zweigstelle,int *retval);
 DLL_EXPORT const char *lut_bic_i(int b,int zweigstelle,int *retval);
+DLL_EXPORT const char *lut_bic_h(char *b,int zweigstelle,int *retval);
+DLL_EXPORT const char *lut_bic_hi(int b,int zweigstelle,int *retval);
 DLL_EXPORT int lut_nr(char *b,int zweigstelle,int *retval);
 DLL_EXPORT int lut_nr_i(int b,int zweigstelle,int *retval);
 DLL_EXPORT int lut_pz(char *b,int zweigstelle,int *retval);
@@ -952,6 +905,48 @@ DLL_EXPORT int lut_keine_iban_berechnung(char *iban_blacklist,char *lutfile,int
 DLL_EXPORT int lut_iban_regel(char *b,int zweigstelle,int *retval);
 DLL_EXPORT int lut_iban_regel_i(int b,int zweigstelle,int *retval);
 
+DLL_EXPORT int bic_aenderung(char *bic_name,int mode,int filiale,int*retval);
+DLL_EXPORT int bic_loeschung(char *bic_name,int mode,int filiale,int*retval);
+DLL_EXPORT int bic_iban_regel(char *bic_name,int mode,int filiale,int*retval);
+DLL_EXPORT int bic_nachfolge_blz(char *bic_name,int mode,int filiale,int*retval);
+DLL_EXPORT int bic_nr(char *bic_name,int mode,int filiale,int*retval);
+DLL_EXPORT int bic_pan(char *bic_name,int mode,int filiale,int*retval);
+DLL_EXPORT int bic_plz(char *bic_name,int mode,int filiale,int*retval);
+DLL_EXPORT int bic_pz(char *bic_name,int mode,int filiale,int*retval);
+DLL_EXPORT const char *bic_bic(char *bic_name,int mode,int filiale,int*retval);
+DLL_EXPORT const char *bic_bic_h(char *bic_name,int mode,int filiale,int*retval);
+DLL_EXPORT const char *bic_name(char *bic_name,int mode,int filiale,int*retval);
+DLL_EXPORT const char *bic_name_kurz(char *bic_name,int mode,int filiale,int*retval);
+DLL_EXPORT const char *bic_ort(char *bic_name,int mode,int filiale,int*retval);
+
+DLL_EXPORT int biq_aenderung(int idx,int*retval);
+DLL_EXPORT int biq_loeschung(int idx,int*retval);
+DLL_EXPORT int biq_iban_regel(int idx,int*retval);
+DLL_EXPORT int biq_nachfolge_blz(int idx,int*retval);
+DLL_EXPORT int biq_nr(int idx,int*retval);
+DLL_EXPORT int biq_pan(int idx,int*retval);
+DLL_EXPORT int biq_plz(int idx,int*retval);
+DLL_EXPORT int biq_pz(int idx,int*retval);
+DLL_EXPORT const char *biq_bic(int idx,int*retval);
+DLL_EXPORT const char *biq_bic_h(int idx,int*retval);
+DLL_EXPORT const char *biq_name(int idx,int*retval);
+DLL_EXPORT const char *biq_name_kurz(int idx,int*retval);
+DLL_EXPORT const char *biq_ort(int idx,int*retval);
+
+DLL_EXPORT int iban_aenderung(char *iban,int filiale,int*retval);
+DLL_EXPORT int iban_loeschung(char *iban,int filiale,int*retval);
+DLL_EXPORT int iban_iban_regel(char *iban,int filiale,int*retval);
+DLL_EXPORT int iban_nachfolge_blz(char *iban,int filiale,int*retval);
+DLL_EXPORT int iban_nr(char *iban,int filiale,int*retval);
+DLL_EXPORT int iban_pan(char *iban,int filiale,int*retval);
+DLL_EXPORT int iban_plz(char *iban,int filiale,int*retval);
+DLL_EXPORT int iban_pz(char *iban,int filiale,int*retval);
+DLL_EXPORT const char *iban_bic(char *iban,int filiale,int*retval);
+DLL_EXPORT const char *iban_bic_h(char *iban,int filiale,int*retval);
+DLL_EXPORT const char *iban_name(char *iban,int filiale,int*retval);
+DLL_EXPORT const char *iban_name_kurz(char *iban,int filiale,int*retval);
+DLL_EXPORT const char *iban_ort(char *iban,int filiale,int*retval);
+
 /*
  * ######################################################################
  * # Suche von Banken nach verschiedenen Kriterien                      #
@@ -967,6 +962,7 @@ DLL_EXPORT int lut_iban_regel_i(int b,int zweigstelle,int *retval);
 #define LUT_SUCHE_PLZ         7
 #define LUT_SUCHE_PZ          8
 #define LUT_SUCHE_REGEL       9
+#define LUT_SUCHE_BIC_H      10
 
    /* Defaultwert fr sort/uniq bei Suchfunktionen (=> nur eine Zweigstelle
     * zurckgeben) (betrifft nur PHP, Perl und Ruby, bei denen der Parameter
@@ -983,6 +979,7 @@ DLL_EXPORT int lut_iban_regel_i(int b,int zweigstelle,int *retval);
 DLL_EXPORT int kto_check_idx2blz(int idx,int *zweigstelle,int *retval);
 DLL_EXPORT int konto_check_idx2blz(int idx,int *zweigstelle,int *retval);
 DLL_EXPORT int lut_suche_bic(char *such_name,int *anzahl,int **start_idx,int **zweigstellen_base,char ***base_name,int **blz_base);
+DLL_EXPORT int lut_suche_bic_h(char *such_name,int *anzahl,int **start_idx,int **zweigstellen_base,char ***base_name,int **blz_base);
 DLL_EXPORT int lut_suche_namen(char *such_name,int *anzahl,int **start_idx,int **zweigstellen_base,char ***base_name,int **blz_base);
 DLL_EXPORT int lut_suche_namen_kurz(char *such_name,int *anzahl,int **start_idx,int **zweigstellen_base,char ***base_name,int **blz_base);
 DLL_EXPORT int lut_suche_ort(char *such_name,int *anzahl,int **start_idx,int **zweigstellen_base,char ***base_name,int **blz_base);
@@ -1015,6 +1012,7 @@ DLL_EXPORT int lut_cleanup(void);
 
    /* IBAN-Sachen */
 DLL_EXPORT int ci_check(char *ci);
+DLL_EXPORT int bic_check(char *search_bic,int *cnt);
 DLL_EXPORT int iban_check(char *iban,int *retval);
 DLL_EXPORT const char *iban2bic(char *iban,int *retval,char *blz,char *kto);
 DLL_EXPORT char *iban_gen(char *kto,char *blz,int *retval);
@@ -1023,6 +1021,9 @@ DLL_EXPORT char *iban_bic_gen1(char *blz,char *kto,const char **bicp,int *retval
 DLL_EXPORT int ipi_gen(char *zweck,char *dst,char *papier);
 DLL_EXPORT int ipi_check(char *zweck);
 
+   /* BIC-Funktionen */
+DLL_EXPORT int bic_info(char *bic_name,int mode,int *anzahl,int *start_idx);
+
    /* Rckgabewerte in Klartext umwandeln */
 DLL_EXPORT int kto_check_encoding(int mode);
 DLL_EXPORT int keep_raw_data(int mode);
@@ -1037,6 +1038,9 @@ DLL_EXPORT const char *kto_check_retval2dos(int retval);
    /* Prfziffer (numerisch) in String umwandeln */
 const DLL_EXPORT char *pz2str(int pz,int *ret);
 
+   /* Flag fr neue Prfziffermethoden setzen bzw. abfragen */
+DLL_EXPORT int pz_aenderungen_enable(int set);
+
 /*
  * ######################################################################
  * #               globale Variablen                                    #
