@@ -43,7 +43,7 @@ from ctypes import c_char_p, c_int, c_void_p, create_string_buffer, \
                     POINTER, byref, CDLL, util, cast
 c_int_p = POINTER(c_int)
 
-__version__ = '5.4.0'
+__version__ = '5.4.1'
 
 __all__ = ['get_version', 'lut_load', 'lut_is_valid', 'cleanup',
             'check_iban', 'create_iban', 'get_bic', 'get_name',
@@ -408,48 +408,44 @@ for name, value in KontoCheckError.__dict__.items():
         KontoCheckError._error_codes[value] = name
 
 
-if os.name == 'nt':
-    if hasattr(util, 'find_msvcrt'):
-        msvcrt = util.find_msvcrt()
-    else:
-        # Backport of find_msvcrt for Python 2.5 and below
-        def find_msvcrt():
-            """Return the name of the VC runtime dll"""
-            #For Python 2.3 and up, the version number is included in
-            #sys.version.  For earlier versions, assume the compiler is MSVC 6.
-            prefix = "MSC v."
-            i = sys.version.find(prefix)
-            if i == -1:
-                version = 6
+if os.name == 'nt' and not hasattr(util, 'find_msvcrt'):
+    # Backport of find_msvcrt for Python 2.5 and below
+    def _find_msvcrt():
+        """Return the name of the VC runtime dll"""
+        #For Python 2.3 and up, the version number is included in
+        #sys.version.  For earlier versions, assume the compiler is MSVC 6.
+        prefix = "MSC v."
+        i = sys.version.find(prefix)
+        if i == -1:
+            version = 6
+        else:
+            i = i + len(prefix)
+            s, rest = sys.version[i:].split(" ", 1)
+            majorVersion = int(s[:-2]) - 6
+            minorVersion = int(s[2:3]) / 10.0
+            # I don't think paths are affected by minor version in version 6
+            if majorVersion == 6:
+                minorVersion = 0
+            if majorVersion >= 6:
+                version = majorVersion + minorVersion
             else:
-                i = i + len(prefix)
-                s, rest = sys.version[i:].split(" ", 1)
-                majorVersion = int(s[:-2]) - 6
-                minorVersion = int(s[2:3]) / 10.0
-                # I don't think paths are affected by minor version in version 6
-                if majorVersion == 6:
-                    minorVersion = 0
-                if majorVersion >= 6:
-                    version = majorVersion + minorVersion
-                else:
-                    # we don't know what version of the compiler this is
-                    return None
-            if version <= 6:
-                clibname = 'msvcrt'
-            else:
-                clibname = 'msvcr%d' % (version * 10)
-            # If python was built with in debug mode
-            import imp
-            if imp.get_suffixes()[0][0] == '_d.pyd':
-                clibname += 'd'
-            return clibname+'.dll'
-        msvcrt = find_msvcrt()
-    libpath = msvcrt and util.find_library(msvcrt)
+                # we don't know what version of the compiler this is
+                return None
+        if version <= 6:
+            clibname = 'msvcrt'
+        else:
+            clibname = 'msvcr%d' % (version * 10)
+        # If python was built with in debug mode
+        import imp
+        if imp.get_suffixes()[0][0] == '_d.pyd':
+            clibname += 'd'
+        return clibname+'.dll'
+    libpath = _find_msvcrt()
 else:
     libpath = util.find_library('c')
 
 if not libpath:
-    raise ImportError('c library not found')
+    raise ImportError('C library not found')
 
 libc = CDLL(libpath)
 
